pub struct BuildTasksPackage {
pub base_image: Option<String>,
pub build_dir: Option<String>,
pub configuration: Option<BuildTasksPackageConfiguration>,
pub dependencies: Option<Vec<String>>,
pub git: Option<BuildTasksPackageGit>,
pub maven: Option<BuildTasksPackageMaven>,
pub name: Option<String>,
pub runtime: Option<BuildTasksPackageRuntime>,
pub sources: Option<Vec<BuildTasksPackageSources>>,
pub steps: Option<Vec<String>>,
}Expand description
Application pre publishing a PackageTask, used to package the project
Fields
base_image: Option<String>the base image layer
build_dir: Option<String>workspace directory to use
configuration: Option<BuildTasksPackageConfiguration>The configuration that should be used to perform the Build.
dependencies: Option<Vec<String>>the list of dependencies to use for this build
git: Option<BuildTasksPackageGit>the configuration of the project to build on Git
maven: Option<BuildTasksPackageMaven>the configuration required by Maven for the application build phase
name: Option<String>name of the task
runtime: Option<BuildTasksPackageRuntime>the configuration required for the runtime application
sources: Option<Vec<BuildTasksPackageSources>>the sources to add at build time
steps: Option<Vec<String>>the list of steps to execute (see pkg/builder/)