IntegrationKitSources

Struct IntegrationKitSources 

pub struct IntegrationKitSources {
Show 14 fields pub compression: Option<bool>, pub content: Option<String>, pub content_key: Option<String>, pub content_ref: Option<String>, pub content_type: Option<String>, pub from_kamelet: Option<bool>, pub interceptors: Option<Vec<String>>, pub language: Option<String>, pub loader: Option<String>, pub name: Option<String>, pub path: Option<String>, pub property_names: Option<Vec<String>>, pub raw_content: Option<String>, pub type: Option<String>,
}
SourceSpec defines the configuration for one or more routes to be executed in a certain Camel DSL language.

Fields

compression: Option<bool>

if the content is compressed (base64 encrypted)

content: Option<String>

the source code (plain text)

content_key: Option<String>

the confimap key holding the source content

content_ref: Option<String>

the confimap reference holding the source content

content_type: Option<String>

the content type (tipically text or binary)

from_kamelet: Option<bool>

True if the spec is generated from a Kamelet

interceptors: Option<Vec<String>>

Interceptors are optional identifiers the org.apache.camel.k.RoutesLoader uses to pre/post process sources.

Deprecated: no longer in use.

language: Option<String>

specify which is the language (Camel DSL) used to interpret this source code

loader: Option<String>

Loader is an optional id of the org.apache.camel.k.RoutesLoader that will interpret this source at runtime

name: Option<String>

the name of the specification

path: Option<String>

the path where the file is stored

property_names: Option<Vec<String>>

List of property names defined in the source (e.g. if type is “template”)

raw_content: Option<String>

the source code (binary)

type: Option<String>

Type defines the kind of source described by this object