pub struct IntegrationProfileTraitsMaster {
pub auto: Option<bool>,
pub configuration: Option<BTreeMap<String, Value>>,
pub enabled: Option<bool>,
pub include_delegate_dependencies: Option<bool>,
pub label_key: Option<String>,
pub label_value: Option<String>,
pub resource_name: Option<String>,
pub resource_type: Option<String>,
}Expand description
The configuration of Master trait
Fields
auto: Option<bool>Enables automatic configuration of the trait.
configuration: Option<BTreeMap<String, Value>>Legacy trait configuration parameters.
Deprecated: for backward compatibility.
enabled: Option<bool>Can be used to enable or disable a trait. All traits share this common property.
include_delegate_dependencies: Option<bool>When this flag is active, the operator analyzes the source code to add dependencies required by delegate endpoints.
E.g. when using master:lockname:timer, then camel:timer is automatically added to the set of dependencies.
It’s enabled by default.
label_key: Option<String>Label that will be used to identify all pods contending the lock. Defaults to “camel.apache.org/integration”.
label_value: Option<String>Label value that will be used to identify all pods contending the lock. Defaults to the integration name.
resource_name: Option<String>Name of the configmap that will be used to store the lock. Defaults to “
resource_type: Option<String>Type of Kubernetes resource to use for locking (“ConfigMap” or “Lease”). Defaults to “Lease”.