pub struct IntegrationStatusTraitsPdb {
pub configuration: Option<BTreeMap<String, Value>>,
pub enabled: Option<bool>,
pub max_unavailable: Option<String>,
pub min_available: Option<String>,
}Expand description
The configuration of PDB trait
Fields
configuration: Option<BTreeMap<String, Value>>Legacy trait configuration parameters.
Deprecated: for backward compatibility.
enabled: Option<bool>Can be used to enable or disable a trait. All traits share this common property.
The number of pods for the Integration that can be unavailable after an eviction.
It can be either an absolute number or a percentage (default 1 if min-available is also not set).
Only one of max-unavailable and min-available can be specified.
min_available: Option<String>The number of pods for the Integration that must still be available after an eviction.
It can be either an absolute number or a percentage.
Only one of min-available and max-unavailable can be specified.