IntegrationTemplateSpecInitContainersLifecyclePostStart

Struct IntegrationTemplateSpecInitContainersLifecyclePostStart 

pub struct IntegrationTemplateSpecInitContainersLifecyclePostStart {
    pub exec: Option<IntegrationTemplateSpecInitContainersLifecyclePostStartExec>,
    pub http_get: Option<IntegrationTemplateSpecInitContainersLifecyclePostStartHttpGet>,
    pub sleep: Option<IntegrationTemplateSpecInitContainersLifecyclePostStartSleep>,
    pub tcp_socket: Option<IntegrationTemplateSpecInitContainersLifecyclePostStartTcpSocket>,
}
PostStart is called immediately after a container is created. If the handler fails, the container is terminated and restarted according to its restart policy. Other management of the container blocks until the hook completes. More info: https://kubernetes.io/docs/concepts/containers/container-lifecycle-hooks/#container-hooks

Fields

exec: Option<IntegrationTemplateSpecInitContainersLifecyclePostStartExec>

Exec specifies a command to execute in the container.

http_get: Option<IntegrationTemplateSpecInitContainersLifecyclePostStartHttpGet>

HTTPGet specifies an HTTP GET request to perform.

sleep: Option<IntegrationTemplateSpecInitContainersLifecyclePostStartSleep>

Sleep represents a duration that the container should sleep.

tcp_socket: Option<IntegrationTemplateSpecInitContainersLifecyclePostStartTcpSocket>

Deprecated. TCPSocket is NOT supported as a LifecycleHandler and kept for backward compatibility. There is no validation of this field and lifecycle hooks will fail at runtime when it is specified.