pub struct PipeIntegrationTemplateSpecInitContainersLifecycle {
pub post_start: Option<PipeIntegrationTemplateSpecInitContainersLifecyclePostStart>,
pub pre_stop: Option<PipeIntegrationTemplateSpecInitContainersLifecyclePreStop>,
pub stop_signal: Option<String>,
}Expand description
Actions that the management system should take in response to container lifecycle events. Cannot be updated.
Fields
post_start: Option<PipeIntegrationTemplateSpecInitContainersLifecyclePostStart>PostStart is called immediately after a container is created. If the handler fails, the container is terminated and restarted according to its restart policy. Other management of the container blocks until the hook completes. More info: https://kubernetes.io/docs/concepts/containers/container-lifecycle-hooks/#container-hooks
pre_stop: Option<PipeIntegrationTemplateSpecInitContainersLifecyclePreStop>PreStop is called immediately before a container is terminated due to an API request or management event such as liveness/startup probe failure, preemption, resource contention, etc. The handler is not called if the container crashes or exits. The Pod’s termination grace period countdown begins before the PreStop hook is executed. Regardless of the outcome of the handler, the container will eventually terminate within the Pod’s termination grace period (unless delayed by finalizers). Other management of the container blocks until the hook completes or until the termination grace period is reached. More info: https://kubernetes.io/docs/concepts/containers/container-lifecycle-hooks/#container-hooks
stop_signal: Option<String>StopSignal defines which signal will be sent to a container when it is being stopped. If not specified, the default is defined by the container runtime in use. StopSignal can only be set for Pods with a non-empty .spec.os.name