pub struct IntegrationProfileStatusTraitsMount {
pub configs: Option<Vec<String>>,
pub configuration: Option<BTreeMap<String, Value>>,
pub empty_dirs: Option<Vec<String>>,
pub enabled: Option<bool>,
pub hot_reload: Option<bool>,
pub resources: Option<Vec<String>>,
pub scan_kamelets_implicit_label_secrets: Option<bool>,
pub volumes: Option<Vec<String>>,
}Expand description
The configuration of Mount trait
Fields
configs: Option<Vec<String>>A list of configuration pointing to configmap/secret. The configuration are expected to be UTF-8 resources as they are processed by runtime Camel Context and tried to be parsed as property files. They are also made available on the classpath in order to ease their usage directly from the Route. Syntax: [configmap|secret]:name[/key], where name represents the resource name and key optionally represents the resource key to be filtered
configuration: Option<BTreeMap<String, Value>>Legacy trait configuration parameters.
Deprecated: for backward compatibility.
empty_dirs: Option<Vec<String>>A list of EmptyDir volumes to be mounted. An optional size limit may be configured (default 500Mi). Syntax: name:/container/path[:sizeLimit]
enabled: Option<bool>Deprecated: no longer in use.
hot_reload: Option<bool>Enable “hot reload” when a secret/configmap mounted is edited (default false). The configmap/secret must be
marked with camel.apache.org/integration label to be taken in account. The resource will be watched for any kind change, also for
changes in metadata.
resources: Option<Vec<String>>A list of resources (text or binary content) pointing to configmap/secret. The resources are expected to be any resource type (text or binary content). The destination path can be either a default location or any path specified by the user. Syntax: [configmap|secret]:name[/key][@path], where name represents the resource name, key optionally represents the resource key to be filtered and path represents the destination path
scan_kamelets_implicit_label_secrets: Option<bool>Deprecated: no longer available since version 2.5.
volumes: Option<Vec<String>>A list of Persistent Volume Claims to be mounted. Syntax: [pvcname:/container/path]. If the PVC is not found, the Integration fails. You can use the syntax [pvcname:/container/path:size:accessMode<:storageClass>] to create a dynamic PVC based on the Storage Class provided or the default cluster Storage Class. However, if the PVC exists, the operator would mount it.