pub struct IntegrationStatusTraitsBuilder {Show 22 fields
pub annotations: Option<BTreeMap<String, String>>,
pub base_image: Option<String>,
pub configuration: Option<BTreeMap<String, Value>>,
pub enabled: Option<bool>,
pub incremental_image_build: Option<bool>,
pub limit_cpu: Option<String>,
pub limit_memory: Option<String>,
pub maven_profiles: Option<Vec<String>>,
pub node_selector: Option<BTreeMap<String, String>>,
pub order_strategy: Option<IntegrationStatusTraitsBuilderOrderStrategy>,
pub platforms: Option<Vec<String>>,
pub properties: Option<Vec<String>>,
pub request_cpu: Option<String>,
pub request_memory: Option<String>,
pub strategy: Option<IntegrationStatusTraitsBuilderStrategy>,
pub tasks: Option<Vec<String>>,
pub tasks_filter: Option<String>,
pub tasks_limit_cpu: Option<Vec<String>>,
pub tasks_limit_memory: Option<Vec<String>>,
pub tasks_request_cpu: Option<Vec<String>>,
pub tasks_request_memory: Option<Vec<String>>,
pub verbose: Option<bool>,
}Expand description
The configuration of Builder trait
Fields
annotations: Option<BTreeMap<String, String>>When using pod strategy, annotation to use for the builder pod.
base_image: Option<String>Specify a base image. In order to have the application working properly it must be a container image which has a Java JDK
installed and ready to use on path (ie /usr/bin/java).
configuration: Option<BTreeMap<String, Value>>Legacy trait configuration parameters.
Deprecated: for backward compatibility.
enabled: Option<bool>Deprecated: no longer in use.
incremental_image_build: Option<bool>Use the incremental image build option, to reuse existing containers (default true)
limit_cpu: Option<String>When using pod strategy, the maximum amount of CPU required by the pod builder.
Deprecated: use TasksRequestCPU instead with task name builder.
limit_memory: Option<String>When using pod strategy, the maximum amount of memory required by the pod builder.
Deprecated: use TasksRequestCPU instead with task name builder.
maven_profiles: Option<Vec<String>>A list of references pointing to configmaps/secrets that contains a maven profile.
This configmap/secret is a resource of the IntegrationKit created, therefore it needs to be present in the namespace where the operator is going to create the IntegrationKit.
The content of the maven profile is expected to be a text containing a valid maven profile starting with <profile> and ending with </profile> that will be integrated as an inline profile in the POM.
Syntax: [configmap|secret]:name[/key], where name represents the resource name, key optionally represents the resource key to be filtered (default key value = profile.xml).
node_selector: Option<BTreeMap<String, String>>Defines a set of nodes the builder pod is eligible to be scheduled on, based on labels on the node.
order_strategy: Option<IntegrationStatusTraitsBuilderOrderStrategy>The build order strategy to use, either dependencies, fifo or sequential (default is the platform default)
platforms: Option<Vec<String>>The list of manifest platforms to use to build a container image (default linux/amd64).
properties: Option<Vec<String>>A list of properties to be provided to the build task
request_cpu: Option<String>When using pod strategy, the minimum amount of CPU required by the pod builder.
Deprecated: use TasksRequestCPU instead with task name builder.
request_memory: Option<String>When using pod strategy, the minimum amount of memory required by the pod builder.
Deprecated: use TasksRequestCPU instead with task name builder.
strategy: Option<IntegrationStatusTraitsBuilderStrategy>The strategy to use, either pod or routine (default routine)
tasks: Option<Vec<String>>A list of tasks to be executed (available only when using pod strategy) with format <name>;<container-image>;<container-command>.
tasks_filter: Option<String>A list of tasks sorted by the order of execution in a csv format, ie, <taskName1>,<taskName2>,....
Mind that you must include also the operator tasks (builder, quarkus-native, package, jib, s2i)
if you need to execute them. Useful only with pod strategy.
tasks_limit_cpu: Option<Vec<String>>A list of limit cpu configuration for the specific task with format <task-name>:<limit-cpu-conf>.
tasks_limit_memory: Option<Vec<String>>A list of limit memory configuration for the specific task with format <task-name>:<limit-memory-conf>.
tasks_request_cpu: Option<Vec<String>>A list of request cpu configuration for the specific task with format <task-name>:<request-cpu-conf>.
tasks_request_memory: Option<Vec<String>>A list of request memory configuration for the specific task with format <task-name>:<request-memory-conf>.
verbose: Option<bool>Enable verbose logging on build components that support it (e.g. Kaniko build pod).
Deprecated: no longer in use