pub struct IntegrationTraitsKnativeService {
pub annotations: Option<BTreeMap<String, String>>,
pub auto: Option<bool>,
pub autoscaling_metric: Option<String>,
pub autoscaling_target: Option<i64>,
pub class: Option<IntegrationTraitsKnativeServiceClass>,
pub configuration: Option<BTreeMap<String, Value>>,
pub enabled: Option<bool>,
pub max_scale: Option<i64>,
pub min_scale: Option<i64>,
pub rollout_duration: Option<String>,
pub timeout_seconds: Option<i64>,
pub visibility: Option<IntegrationTraitsKnativeServiceVisibility>,
}Expand description
The configuration of Knative Service trait
Fields
annotations: Option<BTreeMap<String, String>>The annotations added to route. This can be used to set knative service specific annotations CLI usage example: -t “knative-service.annotations.‘haproxy.router.openshift.io/balance’=true”
auto: Option<bool>Automatically deploy the integration as Knative service when all conditions hold:
- Integration is using the Knative profile
- All routes are either starting from an HTTP based consumer or a passive consumer (e.g.
directis a passive consumer)
autoscaling_metric: Option<String>Configures the Knative autoscaling metric property (e.g. to set concurrency based or cpu based autoscaling).
Refer to the Knative documentation for more information.
autoscaling_target: Option<i64>Sets the allowed concurrency level or CPU percentage (depending on the autoscaling metric) for each Pod.
Refer to the Knative documentation for more information.
class: Option<IntegrationTraitsKnativeServiceClass>Configures the Knative autoscaling class property (e.g. to set hpa.autoscaling.knative.dev or kpa.autoscaling.knative.dev autoscaling).
Refer to the Knative documentation for more information.
configuration: Option<BTreeMap<String, Value>>Legacy trait configuration parameters.
Deprecated: for backward compatibility.
enabled: Option<bool>Can be used to enable or disable a trait. All traits share this common property.
max_scale: Option<i64>An upper bound for the number of Pods that can be running in parallel for the integration. Knative has its own cap value that depends on the installation.
Refer to the Knative documentation for more information.
min_scale: Option<i64>The minimum number of Pods that should be running at any time for the integration. It’s zero by default, meaning that the integration is scaled down to zero when not used for a configured amount of time.
Refer to the Knative documentation for more information.
rollout_duration: Option<String>Enables to gradually shift traffic to the latest Revision and sets the rollout duration.
It’s disabled by default and must be expressed as a Golang time.Duration string representation,
rounded to a second precision.
timeout_seconds: Option<i64>The maximum duration in seconds that the request instance is allowed to respond to a request. This field propagates to the integration pod’s terminationGracePeriodSeconds
Refer to the Knative documentation for more information.
visibility: Option<IntegrationTraitsKnativeServiceVisibility>Setting cluster-local, Knative service becomes a private service.
Specifically, this option applies the networking.knative.dev/visibility label to Knative service.
Refer to the Knative documentation for more information.